import { deepmergeCustom } from "deepmerge-ts";
const defaultMainConfig = {
  root: "",
  base: "/",
  public: "public",
  out: "dist",
  assets: {
    entry: "",
    outDir: "assets",
    outName: "[name]",
    images: {
      outDir: "assets/images",
      outName: "[name]",
      remoteName: "remote",
      optimize: {
        layout: "constrained",
        breakpoints: [
          320,
          400,
          640,
          800,
          1024,
          1280,
          1440,
          1920,
          2560,
          2880,
          3840
        ],
        resolution: [1, 2],
        format: "inherit",
        formatOptions: {},
        quality: void 0,
        aspect: void 0,
        background: void 0,
        fit: "cover",
        position: "centre"
      }
    },
    svgr: {
      svgrOptions: {}
    },
    icons: {
      srcDir: "src/assets/icons",
      outDir: "assets/images",
      outName: "[dirname]",
      svgstoreOptions: {
        cleanSymbols: ["fill", "stroke", "stroke-linejoin", "stroke-width"]
      }
    },
    fonts: {
      outDir: "assets/fonts",
      outName: "[name]"
    },
    bundle: {
      outName: "bundle"
    },
    partial: {
      usePreact: false,
      useIntersectionObserver: true,
      outName: "hydrate",
      rootAttrSuffix: "partial-hydration",
      rootValuePrefix: "ph",
      rootDOMElement: "div",
      rootStyle: { display: "contents" },
      intersectionObserverOptions: {
        root: null,
        rootMargin: "0px",
        thresholds: [0]
      }
    }
  },
  resolve: {
    alias: []
  },
  css: {
    modules: {
      scopeBehaviour: "local",
      globalModulePaths: [],
      generateScopedName: void 0,
      hashPrefix: "",
      localsConvention: "camelCaseOnly"
    },
    preprocessorOptions: {
      scss: {},
      less: {},
      stylus: {}
    }
  },
  markdown: {
    useRemarkGfm: true,
    useRehypeHighlight: true,
    remarkGfmOptions: {},
    rehypeHighlightOptions: {},
    mdxOptions: {
      remarkPlugins: [],
      rehypePlugins: []
    }
  },
  search: {
    outDir: "assets",
    outName: "search",
    include: ["**/*"],
    exclude: ["/404"],
    baseUrl: "",
    trimTitle: "",
    targetSelector: "[data-search]",
    hit: {
      minLength: 3,
      number: false,
      english: true,
      hiragana: false,
      katakana: true,
      kanji: true
    }
  },
  storyapp: {
    useImport: false,
    outDir: "story"
  },
  delivery: {
    include: ["**/*"],
    exclude: ["/404"],
    trimTitle: "",
    sortBy: "path",
    archives: []
  },
  beautify: {
    useHtml: true,
    useAssets: false,
    htmlOptions: {
      indent_size: 2,
      max_preserve_newlines: 0,
      indent_inner_html: true,
      extra_liners: [],
      inline: ["span", "strong", "b", "small", "del", "s", "code", "br", "wbr"]
    },
    cssOptions: {
      indent_size: 2,
      space_around_combinator: true
    },
    jsOptions: {
      indent_size: 2
    }
  },
  vite: {}
};
async function resolveMainConfig(userConfig) {
  const defaultConfig = defaultMainConfig;
  const inlineConfig = userConfig || {};
  const customDeepmerge = deepmergeCustom({
    mergeArrays: false
  });
  const mergedConfig = customDeepmerge(
    defaultConfig,
    inlineConfig
  );
  return mergedConfig;
}
export {
  defaultMainConfig,
  resolveMainConfig
};
