import path from "node:path";
import fs from "fs-extra";
function getHtmlPath(pathname) {
  let fileName = pathname.endsWith("/") ? path.join(pathname, "index.html") : pathname + ".html";
  fileName = fileName.replace(/^\//, "");
  return fileName;
}
function getNodeModulesPath(root) {
  if (fs.existsSync(path.join(root, "package.json"))) {
    return path.join(root, "node_modules");
  } else {
    return path.join(process.cwd(), "node_modules");
  }
}
function getUniquePaths(paths, excludes) {
  const uniquePaths = [...new Set(paths)].sort();
  if (excludes) {
    return uniquePaths.filter((url) => !excludes.includes(url));
  } else {
    return uniquePaths;
  }
}
function isLocalPath(root, url) {
  if (!url)
    return false;
  try {
    const { protocol } = new URL(url);
    if (protocol) {
      return false;
    }
  } catch (_) {
  }
  const filePath = path.join(root, url);
  return fs.existsSync(filePath);
}
export {
  getHtmlPath,
  getNodeModulesPath,
  getUniquePaths,
  isLocalPath
};
